==> seedsui-react-2.6.2.tgz: package/es/Dot/Dot.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Dot = (_temp = _class = function (_Component) {
  _inherits(Dot, _Component);

  function Dot(props) {
    _classCallCheck(this, Dot);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Dot.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        className = _props.className,
        style = _props.style,
        size = _props.size,
        others = _objectWithoutProperties(_props, ['className', 'style', 'size']);

    return React.createElement('i', _extends({ ref: function ref(el) {
        _this2.$el = el;
      }, className: 'dot' + (className ? ' ' + className : ''), style: Object.assign(style, size ? { width: size, height: size } : {}) }, others));
  };

  return Dot;
}(Component), _class.defaultProps = {
  style: {}
}, _temp);
export { Dot as default };
Dot.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  style: PropTypes.object,
  size: PropTypes.string
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Dot/Dot.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Dot = (_temp = _class = function (_Component) {
  _inherits(Dot, _Component);

  function Dot(props) {
    _classCallCheck(this, Dot);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Dot.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        style = _props.style,
        size = _props.size,
        others = _objectWithoutProperties(_props, ['style', 'size']);

    return React.createElement('i', _extends({ ref: function ref(el) {
        _this2.$el = el;
      } }, others, { className: 'dot' + (others.className ? ' ' + others.className : ''), style: Object.assign(size ? { width: size, height: size } : {}, style || {}) }));
  };

  return Dot;
}(Component), _class.defaultProps = {}, _temp);
export { Dot as default };
Dot.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  size: PropTypes.string
} : {};
